validate_zpaq_rate_method

Function validate_zpaq_rate_method 

pub fn validate_zpaq_rate_method(method: &str) -> Result<(), String>
Validate that a ZPAQ method string is streamable and usable for rate modeling. Validate that method is streamable and accepted by the ZPAQ backend.